# frozen_string_literal: true

require 'cgi'

module Jekyll
  class Embed
    class Content
      URL_RE = %r{(<p[^>]*>[\s\n]*(<a[^>]*>)?[\s\n]*(https?://[^<\s\n]+)[\s\n]*(</a>)?[\s\n]*</p>)}m.freeze

      class << self
        # Find URLs on paragraphs.  We do it after rendering because
        # sometimes we use HTML instead of pure Markdown and this way we
        # catch both.
        def embed!(content)
          content.gsub!(URL_RE) do |match|
            url = CGI.unescapeHTML(Regexp.last_match(3))
            embed = Jekyll::Embed.embed url

            if embed == url
              match
            else
              embed
            end
          end
        end
      end
    end
  end
end

Jekyll::Hooks.register :posts, :post_convert do |post|
  Jekyll::Embed::Content.embed! post.content
end
